@@ -2,9 +2,9 @@ from cisco_config_parser import ConfigParser
 
 file = "/Users/ahmad/running_config.txt"
 
-parser = ConfigParser(file=file)
+parser = ConfigParser(content=file, method="file")
 
-obj = parser.get_switchport(mode="trunk")
+obj = parser.ios_get_switchport(mode="trunk")
 
 for i in obj:
     print(i.get_trunk)
\ No newline at end of file
